@@ -43,7 +43,9 @@ namespace Twitterizer.Commands
     /// Creates a friendship between the authenticated user and another user
     /// </summary>
     [AuthorizedCommandAttribute]
+#if !SILVERLIGHT
     [Serializable]
+#endif
     internal sealed class CreateFriendshipCommand : Core.TwitterCommand<TwitterUser>
     {
         /// <summary>
@@ -114,7 +116,7 @@ namespace Twitterizer.Commands
         {
             if (this.UserId > 0)
             {
-                this.RequestParameters.Add("user_id", this.UserId.ToString(CultureInfo.InvariantCulture));
+                this.RequestParameters.Add("user_id", this.UserId.ToString("#"));
             }
             else if (!string.IsNullOrEmpty(this.UserName))
             {
