@@ -42,7 +42,9 @@ namespace Twitterizer.Commands
     /// The show friendship command class.
     /// </summary>
     [AuthorizedCommandAttribute]
+#if !SILVERLIGHT
     [Serializable]
+#endif
     internal sealed class ShowFriendshipCommand : Core.TwitterCommand<TwitterRelationship>
     {
         /// <summary>
@@ -117,7 +119,7 @@ namespace Twitterizer.Commands
         {
             if (this.SourceId > 0)
             {
-                this.RequestParameters.Add("source_id", this.SourceId.ToString(CultureInfo.InvariantCulture));
+                this.RequestParameters.Add("source_id", this.SourceId.ToString("#"));
             }
             else if (!string.IsNullOrEmpty(this.SourceScreenName))
             {
@@ -126,7 +128,7 @@ namespace Twitterizer.Commands
 
             if (this.TargetId > 0)
             {
-                this.RequestParameters.Add("target_id", this.TargetId.ToString(CultureInfo.InvariantCulture));
+                this.RequestParameters.Add("target_id", this.TargetId.ToString("#"));
             }
             else if (!string.IsNullOrEmpty(this.TargetScreenName))
             {
