@@ -34,30 +34,25 @@
 
 namespace Twitterizer.Commands
 {
-    using System;
     using System.Globalization;
-    using Twitterizer.Core;
+    using Core;
 
     /// <summary>
     /// The Paged Timeline Command class. Provides common functionality for all of the paged timeline command classes.
     /// </summary>
-    /// <typeparam name="T"></typeparam>
 #if !SILVERLIGHT
-    [Serializable]
+    [System.Serializable]
 #endif
-    internal abstract class PagedTimelineCommand<T> : TwitterCommand<TwitterStatusCollection>
-        where T : ITwitterObject
+    internal abstract class PagedTimelineCommand : TwitterCommand<TwitterStatusCollection>
     {
-        private NumberFormatInfo numberFormat = CultureInfo.InvariantCulture.NumberFormat;
-
         /// <summary>
-        /// Initializes a new instance of the <see cref="PagedTimelineCommand&lt;T&gt;"/> class.
+        /// Initializes a new instance of the <see cref="PagedTimelineCommand"/> class.
         /// </summary>
         /// <param name="httpMethod">The HTTP method.</param>
         /// <param name="endPoint">The end point.</param>
         /// <param name="tokens">The tokens.</param>
         /// <param name="optionalProperties">The optional properties.</param>
-        public PagedTimelineCommand(HTTPVerb httpMethod, string endPoint, OAuthTokens tokens, OptionalProperties optionalProperties)
+        protected PagedTimelineCommand(HTTPVerb httpMethod, string endPoint, OAuthTokens tokens, OptionalProperties optionalProperties)
             : base(httpMethod, endPoint, tokens, optionalProperties)
         {
         }
@@ -79,10 +74,10 @@ namespace Twitterizer.Commands
                 return;
             }
             if (options.SinceStatusId > 0)
-                this.RequestParameters.Add("since_id", options.SinceStatusId.ToString(CultureInfo.InvariantCulture));
+                this.RequestParameters.Add("since_id", options.SinceStatusId.ToString("#"));
 
             if (options.MaxStatusId > 0)
-                this.RequestParameters.Add("max_id", options.MaxStatusId.ToString(CultureInfo.InvariantCulture));
+                this.RequestParameters.Add("max_id", options.MaxStatusId.ToString("#"));
 
             if (options.Count > 0)
                 this.RequestParameters.Add("count", options.Count.ToString(CultureInfo.InvariantCulture));
