@@ -24,6 +24,7 @@ using System.IO;
 using System.Text;
 using System.Collections;
 using System.Collections.Specialized;
+using System.ComponentModel;
 using System.Threading;
 using System.Net;
 using System.Net.Sockets;
@@ -102,8 +103,10 @@ namespace agsXMPP
 		private		bool					m_UseSSL			= false;
 #if (CF || CF_2) && !BCCRYPTO
         private     bool                    m_UseStartTLS       = false;
+        private bool f_ForceStartTLS = false;
 #else
         private		bool					m_UseStartTLS		= true;
+        private bool f_ForceStartTLS = true;
 #endif
         private     bool                    m_UseCompression    = false;
 		internal	bool					m_Binded			= false;
@@ -311,6 +314,7 @@ namespace agsXMPP
         /// <summary>
 		/// use "old style" ssl for this connection (Port 5223).
 		/// </summary>
+        [Obsolete("Try to use ForceStartTls instead")]
 		public bool UseSSL
 		{
 			get	{ return m_UseSSL; }
@@ -326,6 +330,16 @@ namespace agsXMPP
 #endif
 		}
 
+        public bool ForceStartTls {
+            get {
+                return f_ForceStartTLS;
+            }
+            set {
+                UseStartTLS = UseStartTLS || value;
+                f_ForceStartTLS = value;
+            }
+        }
+
 		/// <summary>
 		/// use Start-TLS on this connection when the server supports it. Make sure UseSSL is false when 
 		/// you want to use this feature.
@@ -500,6 +514,8 @@ namespace agsXMPP
         		
 		public event ObjectHandler				OnClose;
 
+        public event EventHandler<SendingServiceUnavailableEventArgs> SendingServiceUnavailable;
+
 
         /// <summary>
         /// This event is raised when a response to a roster query is received. The roster query contains the contact list.
@@ -709,6 +725,12 @@ namespace agsXMPP
 				CleanupSession();
 		}
 
+        protected virtual void OnSendingServiceUnavailable(SendingServiceUnavailableEventArgs e)
+        {
+            if (SendingServiceUnavailable != null)
+                SendingServiceUnavailable(this, e);
+        }
+
         public override void SocketOnError(object sender, Exception ex)
         {
             base.SocketOnError(sender, ex);
@@ -978,7 +1000,7 @@ namespace agsXMPP
 			AuthIq iq = new AuthIq(IqType.get, new Jid(base.Server));
 			iq.Query.Username = this.m_Username;
 
-			IqGrabber.SendIq(iq, new IqCB(OnGetAuthInfo), null);
+            IqGrabber.SendIq(iq, OnGetAuthInfo);
 		}
 
 		/// <summary>
@@ -1024,7 +1046,9 @@ namespace agsXMPP
 			regIq.Query.Username = this.m_Username;
 			regIq.Query.Password = newPass;
 			
-			IqGrabber.SendIq(regIq, new IqCB(OnChangePasswordResult), newPass);
+            IqGrabber.SendIq(regIq,
+                (object sender, IQEventArgs e) => OnChangePasswordResult(e, newPass)
+            );
 		}
 
 		/// <summary>
@@ -1033,17 +1057,18 @@ namespace agsXMPP
 		/// <param name="sender"></param>
 		/// <param name="iq"></param>
 		/// <param name="data">contains the new password</param>
-		private void OnChangePasswordResult(object sender, IQ iq, object data)
+        private void OnChangePasswordResult(IQEventArgs e, string newPass)
 		{
-			if (iq.Type == IqType.result)
+            if (e.IQ.Type == IqType.result)
 			{
 				if(OnPasswordChanged!=null)
 					OnPasswordChanged(this);
 				
 				// Set the new password in the Password property on sucess
-				m_Password = (string) data;
+                m_Password = newPass;
+                e.Handled = true;
 			}
-			else if (iq.Type == IqType.error)
+            else if (e.IQ.Type == IqType.error)
 			{
 				/*
 				The server or service SHOULD NOT return the original XML sent in 
@@ -1078,7 +1103,7 @@ namespace agsXMPP
 				*/
 
 				if(OnRegisterError!=null)
-					OnRegisterError(this, iq);
+                    OnRegisterError(this, e.IQ);
 			}
         }
 
@@ -1089,23 +1114,26 @@ namespace agsXMPP
         /// requests the registration fields
         /// </summary>
         /// <param name="obj">object which contains the features node which we need later for login again</param>
-        private void GetRegistrationFields(object data)
+        void GetRegistrationFields(Element elem)
         {
             // <iq type='get' id='reg1'>
             //  <query xmlns='jabber:iq:register'/>
             // </iq>
 
             RegisterIq regIq = new RegisterIq(IqType.get, new Jid(base.Server));
-            IqGrabber.SendIq(regIq, new IqCB(OnRegistrationFieldsResult), data);
+            IqGrabber.SendIq(regIq,
+                (object sender, IQEventArgs e) =>
+                    OnRegistrationFieldsResult(e, elem)
+            );
         }
 
-        private void OnRegistrationFieldsResult(object sender, IQ iq, object data)
+        void OnRegistrationFieldsResult(IQEventArgs e, Element data)
         {
-            if (iq.Type != IqType.error)
+            if (e.IQ.Type != IqType.error)
             {
-                if (iq.Query is Register)
+                if (e.IQ.Query is Register)
                 {
-                    RegisterEventArgs args = new RegisterEventArgs(iq.Query as Register);
+                    RegisterEventArgs args = new RegisterEventArgs(e.IQ.Query as Register);
                     if (OnRegisterInformation != null)
                         OnRegisterInformation(this, args);
 
@@ -1125,17 +1153,21 @@ namespace agsXMPP
                     {
                         regIq.Query = args.Register;
                     }
-                    IqGrabber.SendIq(regIq, new IqCB(OnRegisterResult), data);
+                    IqGrabber.SendIq(regIq,
+                        (object sender, IQEventArgs ev) => OnRegisterResult(ev, data)
+                    );
+                    e.Handled = true;
                 }
             }
             else
             {
                 if (OnRegisterError != null)
-                    OnRegisterError(this, iq);
+                    OnRegisterError(this, e.IQ);
+                e.Handled = true; // not really
             }
         }
         
-        private void OnRegisterResult(object sender, IQ iq, object data)
+        private void OnRegisterResult(IQEventArgs e, Element data)
 		{
 			/*
 			Example 6. Host Informs Entity of Failed Registration (Username Conflict)
@@ -1164,7 +1196,7 @@ namespace agsXMPP
 			</error>
 			</iq>
 			*/
-            if (iq.Type == IqType.result)
+            if (e.IQ.Type == IqType.result)
             {
                 DoChangeXmppConnectionState(XmppConnectionState.Registered);
                 if (OnRegistered != null)
@@ -1174,23 +1206,28 @@ namespace agsXMPP
                 { 
                     // init sasl login
                     InitSaslHandler();
-                    m_SaslHandler.OnStreamElement(this, data as Node);
+                    var eventArgs = new ElementEventArgs(data);
+                    m_SaslHandler.OnStreamElement(this, eventArgs);
+                    if (eventArgs.Handled) {
+                        e.Handled = true;
+                    }
                 }
                 else
                 {
                     // old jabber style login
                     RequestLoginInfo();
+                    e.Handled = true;
                 }
             }
-            else if (iq.Type == IqType.error)
+            else if (e.IQ.Type == IqType.error)
             {
                 if (OnRegisterError != null)
-                    OnRegisterError(this, iq);
+                    OnRegisterError(this, e.IQ);
             }
         }
         #endregion
 
-        private void OnGetAuthInfo(object sender, IQ iq, object data)
+        private void OnGetAuthInfo(object sender, IQEventArgs e)
 		{
 			// We get smth like this and should add password (digest) and ressource
 			// Recv:<iq type="result" id="MX_7"><query xmlns="jabber:iq:auth"><username>gnauck</username><password/><digest/><resource/></query></iq>
@@ -1198,7 +1235,15 @@ namespace agsXMPP
 			//			<query xmlns='jabber:iq:auth'><username>gnauck</username><digest>27c05d464e3f908db3b2ca1729674bfddb28daf2</digest><resource>Office</resource></query>
 			//		</iq>
 			// Recv:<iq id="mx_login" type="result"/> 
+
+            e.Handled = true;
 			
+            var iq = e.IQ;
+            if (iq.Error != null) {
+                FireOnAuthError(iq);
+                return;
+            }
+
 			iq.GenerateId();
 			iq.SwitchDirection();
 			iq.Type = IqType.set;
@@ -1208,7 +1253,7 @@ namespace agsXMPP
 			auth.Resource = this.m_Resource;
 			auth.SetAuth(this.m_Username, this.m_Password, this.StreamId);
 			
-			IqGrabber.SendIq(iq, new IqCB(OnAuthenticate), null);
+            IqGrabber.SendIq(iq, OnAuthenticate);
 		}
 
 		/// <summary>
@@ -1231,15 +1276,16 @@ namespace agsXMPP
 		public void RequestAgents()
 		{			
 			AgentsIq iq = new AgentsIq(IqType.get, new Jid(base.Server));
-			IqGrabber.SendIq(iq, new IqCB(OnAgents), null);
+            IqGrabber.SendIq(iq, OnAgents);
 		}
 
-		private void OnAgents(object sender, IQ iq, object data)
+        private void OnAgents(object sender, IQEventArgs e)
 		{	
+            e.Handled = true;
 			if (OnAgentStart != null)
 				OnAgentStart(this);
 						
-			Agents agents = iq.Query as Agents;
+            Agents agents = e.IQ.Query as Agents;
 			if (agents != null)
 			{
 				foreach (Agent a in agents.GetAgents())
@@ -1251,6 +1297,7 @@ namespace agsXMPP
 
 			if (OnAgentEnd != null)
 				OnAgentEnd(this);			
+            e.Handled = true;
 		}
 		#endregion
 
@@ -1289,14 +1336,15 @@ namespace agsXMPP
 		}
 		#endregion       
 
-		private void OnAuthenticate(object sender, IQ iq, object data)
+        private void OnAuthenticate(object sender, IQEventArgs e)
 		{			
-			if (iq.Type == IqType.result)
+            if (e.IQ.Type == IqType.result)
 			{
                 m_Authenticated = true;
                 RaiseOnLogin();                
+                e.Handled = true;
 			}
-			else if(iq.Type == IqType.error)
+            else if(e.IQ.Type == IqType.error)
 			{
 				/* 
 				 * <iq xmlns="jabber:client" id="agsXMPP_2" type="error">
@@ -1310,7 +1358,7 @@ namespace agsXMPP
 				 * 
 				 */
                 if (OnAuthError!=null)
-					OnAuthError(this, iq);
+                    OnAuthError(this, e.IQ);
 			}
 			
 		}
@@ -1383,32 +1431,44 @@ namespace agsXMPP
 				CleanupSession();
 		}
 
-		public override void StreamParserOnStreamElement(object sender, Node e)
+        public override void StreamParserOnStreamElement(object sender, ElementEventArgs eventArgs)
 		{
-			base.StreamParserOnStreamElement(sender, e);
+            base.StreamParserOnStreamElement(sender, eventArgs);
+            bool handled = false;
+            var e = eventArgs.Element;
 
 			if (e is IQ)
 			{
-				if (OnIq != null)
-					OnIq(this, e as IQ);
-					
-				IQ iq = e as IQ;
+                IQ iq = e as IQ;
+
+                if (OnIq != null) {
+                    var ev = new IQEventArgs(iq);
+                    OnIq(this, ev);
+                    handled = handled || ev.Handled;
+                }
+
 				if ( iq != null && iq.Query != null)
 				{
 					// Roster
-                    if (iq.Query is Roster)
+                    if (iq.Query is Roster) {
                         OnRosterIQ(iq);                   
+                        handled = true;
+                    }
 				}	
 			}
 			else if (e is Message)
 			{
-				if (OnMessage != null)
+                if (OnMessage != null) {
 					OnMessage(this, e as Message);
+                    handled = true;
+                }
 			}
 			else if (e is Presence)
 			{
-				if (OnPresence != null)
+                if (OnPresence != null) {
 					OnPresence(this, e as Presence);
+                    handled = true;
+                }
 			}
 			else if (e is protocol.stream.Features)
 			{
@@ -1421,6 +1481,11 @@ namespace agsXMPP
 					DoChangeXmppConnectionState(XmppConnectionState.Securing);
 					Send(new StartTls());
 				}
+                // connection is not encrypted, doesn't support starttls but tls is forced
+                else if (!ClientSocket.IsEncrypted && !f.SupportsStartTls && ForceStartTls) {
+                    FireOnError(this, new StartTlsException("StartTls is not supported on this server"));
+                    Close();
+                }
                 else
 #endif
                 if (m_UseCompression &&
@@ -1457,6 +1522,7 @@ namespace agsXMPP
                 {
 				    SendStreamHeader(false);
 				    DoChangeXmppConnectionState(XmppConnectionState.Authenticating);
+                    handled = true;
                 }
             }
 #endif
@@ -1469,15 +1535,45 @@ namespace agsXMPP
                 SendStreamHeader(false);
 
                 DoChangeXmppConnectionState(XmppConnectionState.Compressed);
+                handled = true;
 			}
             else if (e is agsXMPP.protocol.Error)
             {
-                if (OnStreamError != null)
+                if (OnStreamError != null) {
                     OnStreamError(this, e as Element);
+                    handled = true;
+                }
             }
 
+            if (handled) {
+                eventArgs.Handled = true;
+            }
 		}
 
+        public override void StreamParserStreamElementNotHandled(object sender, UnhandledElementEventArgs eventArgs)
+        {
+            var stanza = eventArgs.Element as protocol.Base.StanzaWithError;
+            if (stanza == null) {
+                // what should we do here?
+                return;
+            }
+            if (stanza.Error != null) {
+                // don't respond to error messages with service unavailable
+                return;
+            }
+            stanza.Error = new protocol.client.Error(ErrorCondition.ServiceUnavailable);
+            stanza.SwitchDirection();
+
+            // allow the client to prevent this message (privacy/security reasons)
+            var ev = new SendingServiceUnavailableEventArgs(stanza);
+            OnSendingServiceUnavailable(ev);
+            if (ev.Cancel) {
+                // the client has cancelled this
+                return;
+            }
+            Send(eventArgs.Element);
+        }
+
 		public override void StreamParserOnStreamError(object sender, Exception ex)
 		{
 			base.StreamParserOnStreamError(sender, ex);
@@ -1599,4 +1695,15 @@ namespace agsXMPP
 		}
 		#endregion        
 	}
+
+    public class SendingServiceUnavailableEventArgs : CancelEventArgs
+    {
+        public protocol.Base.StanzaWithError Stanza { get; protected set; }
+
+        public SendingServiceUnavailableEventArgs(protocol.Base.StanzaWithError stanza)
+            :base()
+        {
+            Stanza = stanza;
+        }
+    }
 }
\ No newline at end of file
