@@ -25,5 +25,5 @@ namespace agsXMPP.protocol.component
 {
     public delegate void MessageHandler     (object sender, Message msg);
     public delegate void PresenceHandler    (object sender, Presence pres);
-    public delegate void IqHandler          (object sender, IQ iq);
+    public delegate void IqHandler      (object sender, client.IQEventArgs args);
 }
