@@ -45,6 +45,10 @@ namespace Smuxi.Engine
         public new object this[string key]
         {
             get {
+                var value = base["Engine/" + key];
+                if (value != null) {
+                    return value;
+                }
                 return base[_Prefix+key];
             }
             set {
@@ -81,8 +85,8 @@ namespace Smuxi.Engine
             // setting required default values
             prefix = "Frontend/";
             LoadEntry(prefix+"UseLowBandwidthMode", false);
-            LoadEntry(prefix+"ShowQuickJoin", true);
             LoadEntry(prefix+"ShowMenuBar", true);
+            LoadEntry(prefix+"ShowToolBar", true);
             LoadEntry(prefix+"ShowStatusBar", true);
 
             prefix = "Frontend/Engines/";
@@ -114,6 +118,7 @@ namespace Smuxi.Engine
             }
             
             LoadAllEntries("Frontend/"+_UIName);
+            LoadAllEntries("Engine");
         }
         
         public new void Remove(string key)
