@@ -31,14 +31,17 @@ using Smuxi.Common;
 namespace Smuxi.Engine
 {
     [Serializable]
+    [DataContract]
     public class MessageModel : ISerializable
     {
+        static readonly Regex NickRegex = new Regex("^<([^ ]+)> ");
         private DateTime                f_TimeStamp;
         private IList<MessagePartModel> f_MessageParts;
         private MessageType             f_MessageType;
         [NonSerialized]
         private bool                    f_IsCompactable;
 
+        [DataMember]
         public DateTime TimeStamp {
             get {
                 return f_TimeStamp;
@@ -47,19 +50,22 @@ namespace Smuxi.Engine
                 f_TimeStamp = value;
             }
         }
-        
+
+        [DataMember]
         public IList<MessagePartModel> MessageParts {
             get {
                 return f_MessageParts;
             }
         }
 
+        [IgnoreDataMember]
         public bool IsEmpty {
             get {
                 return f_MessageParts.Count == 0;
             }
         }
         
+        [DataMember]
         public MessageType MessageType {
             get {
                 return f_MessageType;
@@ -69,6 +75,7 @@ namespace Smuxi.Engine
             }
         }
         
+        [IgnoreDataMember]
         public bool IsCompactable {
             get {
                 return f_IsCompactable;
@@ -173,7 +180,8 @@ namespace Smuxi.Engine
                 return false;
             }
 
-            if (f_TimeStamp != msg.TimeStamp) {
+            // millisecond precision
+            if (Math.Abs(f_TimeStamp.Subtract(msg.TimeStamp).TotalMilliseconds) > 1) {
                 return false;
             }
             if (f_MessageType != msg.MessageType) {
@@ -257,7 +265,7 @@ namespace Smuxi.Engine
             // meesage itself
             // TODO: extend MessageModel with Origin property
             var msgText = ToString();
-            var match = Regex.Match(msgText, "^<([^ ]+)>");
+            var match = NickRegex.Match(msgText);
             if (match.Success && match.Groups.Count >= 2) {
                 return match.Groups[1].Value;
             }
