@@ -1,7 +1,7 @@
 /*
  * Smuxi - Smart MUltipleXed Irc
  *
- * Copyright (c) 2005-2007, 2010-2011 Mirco Bauer <meebey@meebey.net>
+ * Copyright (c) 2005-2007, 2010-2011, 2013 Mirco Bauer <meebey@meebey.net>
  *
  * Full GPL License: <http://www.gnu.org/licenses/gpl.txt>
  *
@@ -24,19 +24,21 @@ using System;
 using System.Text;
 using System.Runtime.Serialization;
 using System.Security.Cryptography;
+using System.Threading;
 using System.Globalization;
 using Smuxi.Common;
 
 namespace Smuxi.Engine
 {
     [Serializable]
-    public class ContactModel : ITraceable, ISerializable, IComparable<ContactModel>
+    public class ContactModel : ITraceable, ISerializable, IComparable<ContactModel>, IComparable
     {
         private string          _ID;
         private string          _IdentityName;
         private string          _NetworkID;
         private string          _NetworkProtocol;
         private TextMessagePartModel _IdentityNameColored;
+        object IdentityNameSyncRoot { get; set; }
 
         public string ID {
             get {
@@ -44,20 +46,32 @@ namespace Smuxi.Engine
             }
         }
         
+        /// <remarks>
+        /// This property is thread safe.
+        /// </remarks>
         public string IdentityName {
             get {
                 return _IdentityName;
             }
             set {
-                _IdentityName = value;
+                lock (IdentityNameSyncRoot) {
+                    _IdentityName = value;
+                    _IdentityNameColored = null;
+                }
             }
         }
 
+        /// <remarks>
+        /// This property is thread safe.
+        /// </remarks>
         public TextMessagePartModel IdentityNameColored {
             get {
                 if (_IdentityNameColored == null) {
-                    _IdentityNameColored = GetColoredIdentityName(_IdentityName,
-                                                                  null);
+                    lock (IdentityNameSyncRoot) {
+                        _IdentityNameColored = GetColoredIdentityName(
+                            _IdentityName, null
+                        );
+                    }
                 }
                 return _IdentityNameColored;
             }
@@ -100,6 +114,7 @@ namespace Smuxi.Engine
             _IdentityName = identityName;
             _NetworkID = networkID;
             _NetworkProtocol = networkProtocol;
+            IdentityNameSyncRoot = new Object();
         }
         
         protected ContactModel(SerializationInfo info, StreamingContext ctx)
@@ -108,6 +123,8 @@ namespace Smuxi.Engine
                 throw new ArgumentNullException("info");
             }
 
+            IdentityNameSyncRoot = new Object();
+
             SerializationReader sr = SerializationReader.GetReader(info);
             SetObjectData(sr);
         }
@@ -197,6 +214,11 @@ namespace Smuxi.Engine
 
         }
 
+        int IComparable.CompareTo(object contact)
+        {
+            return CompareTo(contact as ContactModel);
+        }
+
         public override bool Equals(object obj)
         {
             var value = obj as ContactModel;
