@@ -292,6 +292,7 @@ namespace Smuxi.Frontend.Gnome
                         break;
                     case Gdk.Key.c:
                     case Gdk.Key.C:
+                    case Gdk.Key.Insert:
                         // only use copy if something is selected in the entry
                         if (Buffer.HasSelection) {
                             e.RetVal = false;
@@ -496,7 +497,7 @@ namespace Smuxi.Frontend.Gnome
                             return;
                         }
                     }
-                    if (Frontend.EngineVersion < new Version(0,8,11)) {
+                    if (Frontend.EngineProtocolVersion < new Version(0,8,11)) {
                         foreach (string msg in msgParts) {
                             ExecuteCommand(msg);
                         }
@@ -849,6 +850,7 @@ namespace Smuxi.Frontend.Gnome
                 _CommandManager = null;
             } else {
                 _CommandManager = new CommandManager(Frontend.Session);
+                _CommandManager.EngineProtocolVersion = Frontend.EngineProtocolVersion;
                 _CommandManager.ExceptionEvent +=
                 delegate(object sender, CommandExceptionEventArgs e) {
                     Gtk.Application.Invoke(delegate {
