@@ -343,6 +343,9 @@ namespace Smuxi.Frontend.Gnome
             foreach (EncodingInfo encInfo in Encoding.GetEncodings()) {
                 try {
                     Encoding enc = Encoding.GetEncoding(encInfo.CodePage);
+                    if (enc == null || enc.EncodingName == null) {
+                        continue;
+                    }
                     string encodingName = enc.EncodingName.ToUpper();
 
                     if (!enc.IsSingleByte && enc != Encoding.UTF8) {
@@ -380,6 +383,9 @@ namespace Smuxi.Frontend.Gnome
                     }
                     store.AppendValues(normalizedBodyName + " - " + encodingName, enc.BodyName.ToUpper());
                 } catch (NotSupportedException) {
+                } catch (ArgumentException) {
+                    // HACK: workaround bug in Mono's Encoding.GetEncoding()
+                    // implementation, see: https://smuxi.im/issues/show/1082
                 }
             }
             cb.Model = store;
