@@ -25,6 +25,9 @@ namespace Smuxi.Frontend.Gnome
 {
     public class ChatTreeView : Gtk.TreeView
     {
+#if LOG4NET
+        private static readonly log4net.ILog f_Logger = log4net.LogManager.GetLogger(System.Reflection.MethodBase.GetCurrentMethod().DeclaringType);
+#endif
         public Gtk.TreeStore TreeStore { get; private set; }
         ThemeSettings ThemeSettings { get; set; }
         int f_CurrentChatNumber;
@@ -40,9 +43,21 @@ namespace Smuxi.Frontend.Gnome
             set {
                 Gtk.TreeIter iter;
                 if (value == null) {
-                    TreeStore.GetIterFirst(out iter);
+                    if (!TreeStore.GetIterFirst(out iter)) {
+                        // no chat views available; this can happen on shutdown
+                        return;
+                    }
                 } else {
                     iter = FindChatIter(value);
+                    if (Gtk.TreeIter.Zero.Equals(iter)) {
+#if LOG4NET
+                        f_Logger.ErrorFormat(
+                            "set_CurrentChatView(): FindChatIter({0}) " +
+                            "returned Gtk.TreeIter.Zero, ignoring...", value
+                        );
+#endif
+                        return;
+                    }
                 }
                 var path = TreeStore.GetPath(iter);
                 // we have to ensure we can make the new selection
@@ -86,6 +101,10 @@ namespace Smuxi.Frontend.Gnome
                     Selection.SelectIter(iter);
                     return;
                 }
+                if (Gtk.TreeIter.Zero.Equals(iter)) {
+                    // no chat views available; this happens during shutdown
+                    return;
+                }
                 var path = TreeStore.GetPath(iter);
                 f_CurrentChatNumber = GetRowNumber(path);
             };
@@ -492,7 +511,9 @@ namespace Smuxi.Frontend.Gnome
         Gtk.TreePath GetPath(int rowNumber)
         {
             Gtk.TreeIter iter;
-            TreeStore.GetIterFirst(out iter);
+            if (!TreeStore.GetIterFirst(out iter)) {
+                return null;
+            }
             var path = TreeStore.GetPath(iter);
             // TODO: clamp upper limit
             int i;
